#!/usr/bin/perl
#
#
# Copyright (C) 2002 M.Beranek, marcus@beranek.de
#
#
#

#
# This script does the following:
#
# 1) try to find mysql.h
# 2) try to find libmysqlclient
# 3) untar sqlguipart
# 4) run configure for sqlguipart with path to mysql.h and libmysqlclient
# 5) run make for sqlguipart
# 6) run make install for sqlguipart
# 7) untar sqlgui
# 8) run configure for sqlgui with path to mysql.h and libmysqlclient
# 9) run make for sqlgui
# 10) run make install for sqlgui
#
#

print "\n\nInstallation-Script for sqlgui\n\n\n";

##############################
##############################
# First find mysql.h

$header = qx{locate mysql.h};

@files = split( "\n", $header );
$s = scalar( @files );
if($s>1){
  print "Found more than one mysql.h:\n----------------------------\n";
  $r = 0;
  for(@files){
    $r++;
    print "[$r]: $_\n"
  }
  print "\n----------------------------\nWhich mysql.h came with your mysql-installation?\nPlease select number: ";
  chop( $number = <STDIN> );
  $headerfile = $files[ $number-1 ]
} else {
  $headerfile = $files[ 0 ]
}
if($s==0){
  fatalerror("No mysql.h found. Please install the MySQL-Development-package\n for your distributuion or install the source-files from www.mysql.com.");
}

print "\nYour mysql.h: $headerfile\n=> Path:";

$headerpath = $headerfile;
$headerpath =~ s/^(.+)\/mysql\.h/\1/g;

print "$headerpath\n\n";


# Then find libmysqlclient.a
$libs = qx{locate libmysqlclient.a};

@files = split( "\n", $libs );
$s = scalar( @files );
if($s>1){
  print "Found more than one library:\n----------------------------\n";
  $r = 0;
  for(@files){
    $r++;
    print "[$r]: $_\n"
  }
  print "\n----------------------------\nPlease select number: ";
  chop( $number = <STDIN> );
  $libfile = $files[ $number-1 ]
} else {
  $libfile = $files[ 0 ]
}
if($s==0){
  fatalerror("No libmysqlclient found. Please install the MySQL-Development-package\n for your distributuion or install the source-files from www.mysql.com.");
}

print "\nYour libmysqlclient: $libfile\n=> Path:";

$libpath = $libfile;
$libpath =~ s/^(.+)\/libmysqlclient\.a/\1/g;

print "$libpath\n\n";


$configure = "./configure --with-extra-includes=$headerpath --with-extra-libs=$libpath";

##############################
##############################
# Look for sqlguipart-xxx.tar.gz:

$sqlguiparts = qx{ls sqlguipart-*.tar.gz};
@files = split( "\n", $sqlguiparts );
$s = scalar( @files );
if($s>1){
  print "Found more than one sqlguipart:\n-------------------------------\n";
  $r = 0;
  for(@files){
    $r++;
    print "[$r]: $_\n"
  }
  print "\n-------------------------------\nPlease select number: ";
  chop( $number = <STDIN> );
  $sqlguipart = $files[ $number-1 ];
}else{
  $sqlguipart = $files[0];
}

if($s==0){
  fatalerror("No sqlguipart-archive found...");
}

# untar the file:
print "Extracting sqlguipart...\n";
system("tar -xzf $sqlguipart");

$sqlguipart =~ s/\.tar\.gz//g;

# Configure  and build sqlguipart
print "\n\nNow running configure-script. Please wait...\n\n";
system( "cd $sqlguipart && $configure > /dev/null");
print "\n\nNow running make. please wait...\n\n";
system( "cd $sqlguipart && make > /dev/null" );
# Install sqlguipart
print "\nNow installing sqlguipart. Please enter root-password.\n\n";
system( "cd $sqlguipart && su -c \"make install\" > /dev/null" );

print "\n\nSince we installed a new library, we may need to run ldconfig\nPlease enter root-password.\n";
system( "su -c \"/sbin/ldconfig\"" );


##############################
##############################
# Look for sqlgui-xxx.tar.gz:

$sqlguis = qx{ls sqlgui-*.tar.gz};
@files = split( "\n", $sqlguis );
$s = scalar( @files );
if($s>1){
  print "Found more than one sqlgui:\n-------------------------------\n";
  $r = 0;
  for(@files){
    $r++;
    print "[$r]: $_\n"
  }
  print "\n-------------------------------\nPlease select number: ";
  chop( $number = <STDIN> );
  $sqlgui = $files[ $number-1 ];
}else{
  $sqlgui = $files[0];
}

if($s==0){
  fatalerror("No sqlgui-archive found...");
}

# untar the file:
print "\n\nOkay, we installed the library.\nNow we are going to install the app.\n";
print "Extracting sqlgui...\n";
system("tar -xzf $sqlgui");

$sqlgui =~ s/\.tar\.gz//g;

# Configure and build sqlgui
print "\n\nNow running configure-script. Please wait ...\n\n";
system( "cd $sqlgui && $configure > /dev/null");
print "\n\nNow running make. please wait...\n\n";
system( "cd $sqlgui && make > /dev/null" );
# Install sqlguipart
print "\nNow installing sqlgui. Please enter root-password.\n";
system( "cd $sqlgui && su -c \"make install\" > /dev/null" );

print "\n\n===================================================================\n";
print "SqlGui should be installed now.\nBe sure to have KDEDIR in your Path.\nI can try to start sqlgui for you now.\nIf sqlgui doesn't start, you may need to adjust your path manually,\nor something went wrong with the intallation.\nIn this case, please read the README-file for further instructions.\n";
print "===================================================================\n";

print "\nShall I start sqlgui now? [y/n]\n";

chop( $runnow = <STDIN> );

if (lc($runnow) eq "y"){
  exec( "sqlgui" )
} else {
  print "\n\nHmmm... ?!?\n\n";
  sleep 3;
  print "I will not run sqlgui...\nI will not run sqlgui...\nI will not run sqlgui...\nI will not run sqlgui...\nI will not run sqlgui...\nI will not run sqlgui...\n\n :(\n\n";
}

##############################
sub fatalerror(){
  ($msg) = @_;
  print "\n======\nERROR:\n======\n$msg\n\naborting...\n\n";
  exit(0);
}
